@@ -409,14 +409,14 @@ def create_adjusted_model_for_percentages(model_src, model_use):
         f.write(content)
 
 
-def create_pfile(input_filename, output_filename, feature_count, data):
+def create_pfile(output_filename, feature_count, data, input_filename):
     """Create a pfile.
-    :param input_filename: path to a file that will be created temporarily
     :param output_filename: name of the pfile that will be created
     :param feature_count: dimension of all features combined
     :type feature_count: int
     :param data: list of (x, y) tuples, where x is the feature vector
                  of dimension ``feature_count`` and y is a label.
+    :param input_filename: path to a file that will be created temporarily
     """
     # TODO: The input_filename should not be necessary!
     with open(input_filename, "w") as f:
