@@ -211,7 +211,8 @@ def get_parser():
     return parser
 
 
-def main(list_ids, model, contact_server, raw_data_id, show_raw, mysql_cfg):
+def main(list_ids, model, contact_server, raw_data_id, show_raw,
+         mysql_cfg='mysql_online'):
     """Main function of view.py."""
     if list_ids:
         preprocessing_desc, _, _ = _get_system(model)
